# [DTWS Module] Progress Bar

[![Build Status](https://travis-ci.org/Kocal/dtws-client-module-progressbar.svg?branch=develop)](https://travis-ci.org/Kocal/dtws-client-module-progressbar)
[![Coverage Status](https://coveralls.io/repos/github/Kocal/dtws-client-module-progressbar/badge.svg?branch=master)](https://coveralls.io/github/Kocal/dtws-client-module-progressbar?branch=master) 

Progress Bar module for [django-tornado-websockets](https://github.com/Kocal/django-tornado-websockets) project.
